## START: Set by rpmautospec
## (rpmautospec version 0.2.5)
%define autorelease(e:s:pb:) %{?-p:0.}%{lua:
    release_number = 5;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{?dist}
## END: Set by rpmautospec

# Sphinx-generated HTML documentation is not suitable for packaging; see
# https://bugzilla.redhat.com/show_bug.cgi?id=2006555 for discussion.
#
# We can generate PDF documentation as a substitute.
%bcond_without doc_pdf

Name:           python-aws-sam-translator
Summary:        Transform SAM templates into AWS CloudFormation templates
Version:        1.42.0
Release:        %autorelease

License:        ASL 2.0
URL:            https://github.com/aws/serverless-application-model
# We use the GitHub tarball instead of the PyPI tarball to get documentation
# and tests.
Source0:        %{url}/archive/v%{version}/serverless-application-model-%{version}.tar.gz

# “refactor: Replace mock with unittest.mock”
# https://github.com/aws/serverless-application-model/pull/2184
#
# Note that this patch fixes mock imports in the develop branch, but there are
# a few tests removed or modified since 1.42.0 that we still need to fix up; we
# do this with sed in %%prep.
Patch0:         %{url}/pull/2184.patch

# The base package is arched because we conditionalize tests; the binary
# packages are all noarch, and there is no compiled code.
%global debug_package %{nil}

BuildRequires:  python3-devel

%if %{with doc_pdf}
BuildRequires:  make
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3-sphinx-latex
BuildRequires:  latexmk
%endif

%global common_description %{expand:
%{summary}.

AWS Serverless Application Model (SAM) is an open-source framework for building
serverless applications.}

%description %{common_description}


%package -n     python3-aws-sam-translator
Summary:        %{summary}

BuildArch:      noarch

%description -n python3-aws-sam-translator %{common_description}


%package        doc
Summary:        Documentation for aws-sam-translator

BuildArch:      noarch

%description doc %{common_description}


%prep
%autosetup -n serverless-application-model-%{version} -p1

# Patch0 (upstream PR#2184) fixes mock imports in the develop branch, but there
# are a few tests removed or modified since 1.42.0 that we still need to fix
# up.
sed -r -i 's/^(from )(mock import )/\1unittest.\2/' \
    tests/model/api/test_api_generator.py \
    tests/model/stepfunctions/test_eventbridge_rule_source.py \
    tests/parser/test_parser.py \

# Comment out a few dev dependencies that we will not use. Then, loosen
# selected semver-pinned dev dependencies, allowing newer versions.
sed -r -i \
    -e 's/^(black|coverage|flake8|pylint|pytest-cov|tox)\b/#\1/' \
    -e 's/^(click|pytest|pyyaml|requests)~=/\1>=/' \
    requirements/dev.txt
# Patch out coverage
sed -r -i '/^addopts[[:blank:]]*=/d' pytest.ini


%generate_buildrequires
%pyproject_buildrequires -x dev


%build
%pyproject_wheel

%if %{with doc_pdf}
sphinx-build -b latex docs %{_vpath_builddir}/_latex
%make_build -C %{_vpath_builddir}/_latex LATEXMKOPTS='-quiet'
%endif


%install
%pyproject_install
%pyproject_save_files samtranslator


%check
%ifarch %{ix86} %{arm32}
# This test only has an expected value for 64-bit platforms. Since we no longer
# need to support 32-bit platforms, we don’t bother trying to fix it:
# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
# https://fedoraproject.org/wiki/Changes/RetireARMv7
k="${k-}${k+ and }not (TestPy27UniStr and test_py27_hash)"
%endif
# See Makefile target “test”. We cannot run the interaction tests because they
# interact with AWS.
%pytest -k "${k-}"


%files -n python3-aws-sam-translator -f %{pyproject_files}
# pyproject-rpm-macros handles LICENSE; verify with “rpm -qL -p …”
%doc README.md


%files doc
%license LICENSE NOTICE
%doc CODE_OF_CONDUCT.md
%doc CONTRIBUTING.md
%doc DESIGN.md
%doc DEVELOPMENT_GUIDE.md
%doc HOWTO.md
%doc INTEGRATION_TESTS.md
%doc README.md
%if %{with doc_pdf}
%doc %{_vpath_builddir}/_latex/SAM.pdf
%endif


%changelog
* Tue May 03 2022 Benjamin A. Beasley <code@musicinmybrain.net> 1.42.0-5
- Work around a failing test on 32-bit builders

* Thu Jan 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> 1.42.0-4
- Remove PyPI mock dependency (upstream PR#2184)

* Fri Dec 17 2021 Benjamin A. Beasley <code@musicinmybrain.net> 1.42.0-3
- Patch out pytest-cov build dependency

* Fri Dec 17 2021 Benjamin A. Beasley <code@musicinmybrain.net> 1.42.0-2
- Add missing license files in -doc subpackage

* Wed Dec 15 2021 Benjamin A. Beasley <code@musicinmybrain.net> 1.42.0-1
- Initial package (close RHBZ#2030436)
